@@ -1,7 +1,9 @@
 package Data::CSel::Selection;
 
-our $DATE = '2019-07-26'; # DATE
-our $VERSION = '0.121'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-04-07'; # DATE
+our $DIST = 'Data-CSel'; # DIST
+our $VERSION = '0.122'; # VERSION
 
 sub new {
     my $class = shift;
@@ -33,7 +35,7 @@ Data::CSel::Selection - Selection object
 
 =head1 VERSION
 
-This document describes version 0.121 of Data::CSel::Selection (from Perl distribution Data-CSel), released on 2019-07-26.
+This document describes version 0.122 of Data::CSel::Selection (from Perl distribution Data-CSel), released on 2020-04-07.
 
 =head1 DESCRIPTION
 
@@ -64,7 +66,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019, 2016 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2019, 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
